@@ -32,7 +32,7 @@ KEYWORDS = {
     "help": ["牛子帮助"],
 }
 
-VERSION = '2.6.0'
+VERSION = '2.6.5'
 HELPPER = f"牛了个牛 v{VERSION}\n可用的指令/功能有：\n" + "、".join(
     [
         KEYWORDS.get("sign_up")[0],
@@ -76,7 +76,7 @@ def message_processor(
     TODO: 抽取 utils 文件的导入
     TODO: 牛子共享排行榜
 
-    TODO：朋友加成
+    TODO: 长度多的人修炼可能失败
     """
     # lazy init database
     lazy_init_database()
@@ -161,6 +161,9 @@ def message_processor(
         return
 
     # >>> 检查阶段
+    # 检查长度精度问题
+    DB.make_sure_user_length_not_zero(qq)
+
     # 检查成就
     badge_msg = BadgeSystem.check_whether_get_new_badge(qq)
     if badge_msg:
@@ -898,6 +901,10 @@ class Chinchin_friends:
         qq = ctx["qq"]
         group = ctx["group"]
         at_qq = ctx["at_qq"]
+        # 不能是自己
+        if qq == at_qq:
+            message_arr = ["无中生友是吧"]
+            return send_message(qq, group, join(message_arr, "\n"))
         config = FriendsSystem.read_config()
         max = config["max"]
         friends_data = FriendsSystem.get_friends_data(qq)
@@ -955,7 +962,8 @@ class Chinchin_friends:
             message_arr = ["他不是你的牛友，又开始了是吧。"]
             return send_message(qq, group, join(message_arr, "\n"))
         # 删除朋友
-        nickname = friends_data.get("latest_speech_nickname")
+        target_user = DB.sub_db_info.get_user_info(at_qq)
+        nickname = target_user.get("latest_speech_nickname")
         if not nickname:
             nickname = "无名英雄"
         message_arr = [
